OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "書籤",
    "You bookmarked \"%s\"" : "您建立了書籤「%s」",
    "%1$s bookmarked \"%2$s\"" : "%1$s 建立了書籤「%2$s」",
    "Someone bookmarked \"%s\"" : "有人建立了書籤「%s」",
    "You deleted \"%s\"" : "您刪除了「%s」",
    "%1$s deleted \"%2$s\"" : "%1$s 刪除了「%2$s」",
    "Someone deleted \"%s\"" : "有人刪除了「%s」",
    "You created folder \"%s\"" : "您建立了資料夾「%s」",
    "%1$s created folder \"%2$s\"" : "%1$s 建立了資料夾「%2$s」",
    "Someone created folder \"%s\"" : "有人建立了資料夾「%s」",
    "You moved folder \"%s\"" : "您移動了資料夾「%s」",
    "%1$s moved folder \"%2$s\"" : "%1$s 移動了資料夾「%2$s」",
    "Someone moved folder \"%s\"" : "有人移動了資料夾「%s」",
    "You deleted folder \"%s\"" : "您刪除了資料夾「%s」",
    "%1$s deleted folder \"%2$s\"" : "%1$s 刪除了資料夾「%2$s」",
    "Someone deleted folder \"%s\"" : "有人刪除了資料夾「%s」",
    "You shared folder \"%1$s\" with %2$s" : "您已與 %2$s 分享「%1$s」",
    "You shared folder \"%s\" with someone" : "您已與某人分享「%s」",
    "%1$s shared folder \"%2$s\" with you" : "%1$s 分享了資料夾「%2$s」給您",
    "Someone shared folder \"%s\" with you" : "有人分享了資料夾「%s」給您",
    "You unshared folder \"%1$s\" with %2$s" : "您已取消與 %2$s 分享的資料夾「%1$s」",
    "You unshared folder \"%s\" with someone" : "您已取消與某人分享的資料夾「%s」",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s 已取消與您分享的資料夾「%2$s」",
    "Someone unshared folder \"%s\" with you" : "某人已取消與你分享的資料夾「%s」",
    "No file provided for import" : "未提供要匯入的檔案",
    "Unsupported file type for import" : "匯入不支援的檔案格式",
    "Bookmarks shared by %s" : "由 %s 分享的書籤",
    "Frequent bookmarks" : "常用書籤",
    "Recent bookmarks" : "最近的書籤",
    "Bookmark" : "書籤",
    "Bookmark deleted" : "書籤已刪除",
    "Bookmark created" : "書籤已建立",
    "Bookmark moved" : "書籤已移動",
    "Bookmark updated" : "書籤已更新",
    "Create bookmark" : "建立書籤",
    "Takes a link and adds it to your collection of bookmarks." : "取得連結並新增到您的書籤集合中。",
    "Bookmarks Backups" : "書籤備份",
    "Enter new title" : "輸入新的標題",
    "Select bookmark" : "選擇書籤",
    "You have never clicked this link" : "您從未點擊過此連結",
    "You have clicked this link {count} times" : "您已點擊過此連結 {count} 次",
    "Details" : "細節",
    "Rename" : "重新命名",
    "Copy link" : "複製連結",
    "Move" : "移動",
    "Add to folders" : "新增至資料夾",
    "Put bookmark into trash bin" : "將書籤放到垃圾桶中",
    "Restore bookmark" : "還原書籤",
    "Delete bookmark permanently" : "永久刪除書籤",
    "Do you really want to delete this bookmark?" : "您確定要刪除此標籤嗎？",
    "Link copied to clipboard" : "已複製連結至剪貼簿",
    "Content pending" : "內容待定",
    "This content is being downloaded for offline use. Please check back later." : "此內容已下載供離線使用。請稍後再檢查。",
    "Bookmarked {time} ago" : "{time} 前加入書籤",
    "Bookmarked on {date}" : "於 {date} 加入書籤",
    "These are your deleted items." : "這些是您刪除的項目。",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "網路上的檔案（如照片或 PDF 等）的書籤將會自動儲存到您的 Nextcloud 檔案中，因此即便連結離線，您也仍然可以找到它們。",
    "Searching in the current folder only." : "僅在目前資料夾中搜尋。",
    "Repeat search in all folders" : "在所有資料夾中重複搜尋",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "已加入書籤的連結會定期檢查，無法存取的連結就會在此列出。",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "您可以與其他人分享書籤資料夾。此處列出了與您分享的所有資料夾。",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "一個書籤可以同時位於多個資料夾中。更新它將會更新所有副本。為了方便起見，此處列出了所有重複的書籤。",
    "Open all selected" : "開啟所有選擇項目",
    "Move selection" : "移動選擇",
    "Edit tags of selection" : "編輯選擇標籤",
    "Delete selection" : "刪除選擇",
    "Select all" : "全選",
    "Cancel selection" : "取消選取",
    "Selected {folders} folders and {bookmarks} bookmarks" : "選定的 {folders} 資料夾與 {bookmarks} 書籤",
    "Do you really want to delete these items?" : "您想要刪除這些項目嗎？",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["已選取 %n 書籤"],
    "_Selected %n folder_::_Selected %n folders_" : ["已選取%n個資料夾"],
    "Trash Bin" : "垃圾桶",
    "Go back" : "返回",
    "Share folder" : "分享資料夾",
    "Select one or more tags" : "選取一個或更多標籤",
    "New" : "新增",
    "New bookmark" : "新增書籤",
    "New folder" : "新增資料夾",
    "Change to grid view" : "變更為網格檢視",
    "Change to list view" : "變更為列表檢視",
    "Copy RSS Feed of current view" : "複製目前檢視的 RSS Feed",
    "The RSS feed requires authentication with your Nextcloud credentials" : "RSS feed 需要使用您的 Nextcloud 憑證驗證",
    "Search" : "搜尋",
    "Sort by created date" : "按建立日期排序",
    "Sort by last modified" : "按最後修改時間排序",
    "Sort by title" : "按標題排序",
    "Sort by click count" : "按點擊次數排序",
    "Sort by manual order" : "手動排序",
    "Sort by URL" : "按 URL 排序",
    "RSS feed copied" : "RSS feed 已複製",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["正在新增 %n 書籤至新資料夾"],
    "Enter a link" : "輸入連結",
    "Enter a title" : "輸入標題",
    "No bookmarks found" : "找不到書籤",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} 資料夾與 {bookmarks} 書籤",
    "_%n bookmark_::_%n bookmarks_" : ["%n 書籤"],
    "_%n folder_::_%n folders_" : ["%n 資料夾"],
    "Welcome to Bookmarks" : "歡迎使用書籤",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "此應用程式讓您可以管理網路上您最愛之處的連結。將您的書籤分類至資料夾中，用標籤標記它們並與其他人分享！應用程式會定期檢查您所有連結的可用性，並顯示無法使用的連結。若您在網路上新增指向檔案的連結，該檔案將會自動下載到您的 Nextcloud Files 中。您也可以匯入從其他服務匯出的書籤，或是直接將所有瀏覽器中的書籤與此應用程式同步。",
    "Add a bookmark" : "新增書籤",
    "Import bookmarks" : "匯入書籤",
    "Sync with your browser" : "與您的瀏覽器同步",
    "Select folder" : "選取資料夾",
    "Enter folder title" : "輸入資料夾標題",
    "Shared by {user}" : "由 {user} 分享",
    "Rename folder" : "資料夾更名",
    "Move folder" : "移動資料夾",
    "Put folder into trashbin" : "將資料夾放到垃圾桶中",
    "Restore folder" : "還原資料夾",
    "Delete folder permanently" : "永久刪除資料夾",
    "Do you really want to permanently delete this folder?" : "您真的想要永久刪除此資料夾嗎？",
    "Choose folder" : "選擇資料夾",
    "Submit" : "送出",
    "Cancel" : "取消",
    "Deleting bookmarks" : "正在刪除書籤",
    "Deleting selection" : "正在刪除選擇",
    "Importing bookmarks" : "正在匯入書籤",
    "Moving selection" : "正在移動選擇",
    "Adding selection to folders" : "正在新增選定的項目至資料夾",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["正在移動%n個資料夾和一些書籤"],
    "_Moving %n folder_::_Moving %n folders_" : ["正在移動%n個資料夾"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["正在移動%n個書籤"],
    "All bookmarks" : "所有書籤",
    "Recent" : "近期",
    "Shared with you" : "與您分享",
    "Files" : "檔案",
    "Duplicates" : "重複",
    "Broken links" : "連結損毀",
    "New tag" : "新標籤",
    "Search tags" : "搜尋標籤",
    "Delete" : "刪除",
    "Untagged" : "無標籤",
    "{used} bookmarks of {available} available" : "{used} 書籤，可用 {available}",
    "Settings" : "設定",
    "No bookmarked files" : "沒有已加入書籤的檔案",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "照片或 PDF 等檔案的書籤將會自動儲存到您的 Nextcloud 檔案中，因此即便連結離線，您也仍然可以找到它們。",
    "Nothing found" : "找不到東西",
    "Your search yielded no results in the current folder." : "您的搜尋在目前資料夾中沒有任何結果。",
    "No broken links" : "沒有失效的連結",
    "No shared folders" : "沒有已分享的資料夾",
    "No duplicated bookmarks" : "沒有重複的書籤",
    "No deleted bookmarks" : "沒有已刪除的書籤",
    "You haven't deleted anything yet." : "您尚未刪除任何東西。",
    "No bookmarks here" : "此處無書籤",
    "Add bookmarks manually or import bookmarks from a HTML file." : "手動新增書籤或從 HTML 檔案匯入。",
    "Bookmarks settings" : "書籤設定",
    "Import/Export" : "匯入/匯出",
    "Export bookmarks" : "匯出書籤",
    "Auto-archiving" : "自動封存",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "書籤應用程式可以自動封存您加入書籤的網路內容",
    "Enable archiving" : "啟用封存",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "輸入要儲存書籤檔案的資料夾路徑。",
    "Auto-Backup" : "自動備份",
    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "書籤應用程式可以每天自動備份您的書籤，以防止跨裝置同步書籤時遺失資料。",
    "Enable backups" : "啟用備份",
    "Enter the path of a folder in your Files where backups will be stored." : "輸入在您「檔案」中要儲存備份的資料夾路徑。",
    "Client apps" : "客戶端應用程式",
    "Also check out the collection of client apps that integrate with this app: " : "還要檢查與此應用程式整合的客戶端應用程式集合：",
    "Install web app" : "安裝網路應用程式",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "您可以在裝置主畫面上安裝此應用程式以在您的手機上快速存取您的書籤。如果您不喜歡它，您也可以輕鬆地再次從主畫面移除它。",
    "Install on home screen" : "安裝於主畫面",
    "Bookmarklet" : "書籤",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "將這個拖曳到您的瀏覽器書籤中，並點擊它以快速將網頁加入書籤。",
    "Add to {instanceName}" : "新增到 {instanceName}",
    "Need help?" : "需要協助嗎？",
    "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "若您在使用此書籤應用程式時遇到問題或有任何關於改進的想法，請隨時按此處與我們聯絡。",
    "Support this project" : "支援此專案",
    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "我在這個書籤應用程式上的工作是由自願訂閱模式推動的。如果您覺得我的工作有價值並支援我的工作，我會非常高興。另外，請考慮在 Nextcloud 應用程式商店上對該應用程式進行評論。謝謝你💙",
    "Archive path" : "封存路徑",
    "Backup path" : "備份路徑",
    "Please select \"Add to home screen\" in your browser menu" : "請在您的瀏覽器選單中選取「新增至主畫面」",
    "(Empty title)" : "（空的標題）",
    "Title" : "標題",
    "Link" : "連結",
    "Untitled folder" : "未命名的資料夾",
    "Root folder" : "根資料夾",
    "Tags" : "標籤",
    "Select tags and create new ones" : "選取標籤並建立新的",
    "Notes" : "筆記",
    "Notes for this bookmark …" : "此書籤的註記……",
    "Archived file" : "已封存的檔案",
    "Download file" : "下載檔案",
    "Open file location" : "開啟檔案位置",
    "Created {time} ago" : "建立於 {time} 前",
    "Created on {date}" : "建立於 {date}",
    "Owner" : "擁有者",
    "Sharing" : "分享",
    "Select a user or group" : "選取使用者或群組",
    "Share link" : "分享連結",
    "Reading allowed" : "允許閱讀",
    "Copy RSS feed" : "複製 RSS feed",
    "Delete link" : "刪除連結",
    "Create public link" : "建立公開連結",
    "Resharing allowed" : "允許轉分享",
    "Editing allowed" : "允許編輯",
    "Allow editing" : "允許編輯",
    "Allow resharing" : "允許轉分享",
    "Remove share" : "移除分享",
    "Link copied" : "連結已複製",
    "Privacy" : "隱私",
    "The app will try to access web pages that you add to automatically add information about them." : "該應用程式將嘗試存取您新增的網頁以自動新增關於它們的資訊。",
    "Enable accessing and collecting information from the web pages you add" : "啟用從您新增的網頁存取與蒐集資訊",
    "Performance" : "效能",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "在有大量使用者的站台中，限制每個帳號的書籤數量可能會很有用。",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "每個帳號可以允許的書籤最大數量。（0 為無限制；預設為無限制）",
    "Previews" : "預覽",
    "In order to display real screenshots of your bookmarked websites, the app can use third-party services to generate previews." : "為了顯示您加入書籤的網站的真實螢幕截圖，該應用程式會使用第三方服務來生成預覽。",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "您可以免費在 screeenly.com 註冊或是設定您自己的伺服器。",
    "Screeenly API URL" : "Screeenly API URL",
    "Screeenly API key" : "Screeenly API key",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "ScreenshotMachine API key",
    "Webshot" : "Webshot",
    "Webshot API URL" : "Webshot API URL",
    "Generic screenshot API" : "一般螢幕截圖 API",
    "Sign up with any of the screenshot API providers and put the API URL below. Use the variable {url} as a placeholder for the URL to screenshot. The API must return only the image directly." : "向任何螢幕截圖 API 提供者註冊，並將 API URL 放在下面。使用變數 {url} 作為螢幕截圖 URL 的佔位字串。 API 必須僅直接傳回影像。",
    "Generic API URL" : "一般 API URL",
    "Pageres CLI" : "Pageres CLI",
    "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "只要在您的伺服器上安裝 Sindre Sorhus 開發的 Pageres CLI，書籤應用程式就會找到它。您仍然可以新增額外的 ENV 變數以提供給 pageres，例如在佔位字串中所示：",
    "Pageres ENV variables" : "Pageres ENV 變數",
    "Failed to save settings" : "設定儲存失敗",
    "Failed to load settings" : "設定載入失敗",
    "This URL is already bookmarked! Overwrite?" : "此網址已被加入書籤！要覆寫嗎？",
    "Enter bookmark title" : "輸入書籤標題",
    "Enter bookmark URL" : "輸入書籤 URL",
    "Folder" : "資料夾",
    "Root Folder" : "根資料夾",
    "Save" : "儲存",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "預設情況下停用網路存取。到管理設定中讓書籤應用程式可以擷取預覽與 favicon。",
    "What's new?" : "有什麼新鮮事？",
    "Leave a rating on the Nextcloud App Store" : "在 Nextcloud App Store 留下評分",
    "What" : "什麼",
    "Failed to count unavailable bookmarks" : "計算不可用的書籤失敗",
    "Failed to count archived bookmarks" : "計算已封存的書籤失敗",
    "Failed to count duplicated bookmarks" : "重複書籤計數失敗",
    "Failed to load bookmark" : "載入書籤失敗",
    "Failed to find existing bookmark" : "尋找既有的書籤失敗",
    "Failed to create bookmark" : "建立書籤失敗",
    "Failed to save bookmark" : "儲存書籤失敗",
    "Failed to move bookmark" : "移動書籤失敗",
    "Failed to copy bookmark" : "複製書籤失敗",
    "Failed to delete bookmark" : "刪除書籤失敗",
    "Failed to rename tag" : "重新命名標籤失敗",
    "Failed to load tags" : "載入標籤失敗",
    "Failed to load folders" : "載入資料夾失敗",
    "Failed to load deleted folders" : "載入已刪除資料夾失敗",
    "Failed to load deleted bookmarks" : "載入已刪除的書籤失敗",
    "Failed to delete folder" : "刪除資料夾失敗",
    "Failed to move folder" : "移動資料夾失敗",
    "Failed to create folder" : "建立資料夾失敗",
    "Failed to fetch bookmarks." : "擷取書籤失敗",
    "Failed to store setting" : "儲存設定失敗",
    "Failed to load setting {key}" : "載入設定 {key} 失敗",
    "Failed to update share {shareId}" : "更新分享 {shareId} 失敗",
    "Failed to delete share {shareId}" : "刪除分享 {shareId} 失敗",
    "Create bookmarks for mentioned links" : "為提到的連結建立書籤",
    "No links found in this message" : "此訊息中找不到連結",
    "Bookmarks feed" : "書籤 feed"
},
"nplurals=1; plural=0;");
